/* Store the previous location to be used when sending referrer on navigations */
var actualReferrer = '';
var isFirstPage = true;
/**
 * Useful wrapper around document and window objects
 */

export var utils = {
  /**
   * @returns {string} The referrer of the document
   */
  getDocumentReferrer: function getDocumentReferrer() {
    return document.referrer;
  },

  /**
   * @returns {boolean} Tell if it's the first time we're updating referrering
   */
  checkIsFirstPage: function checkIsFirstPage() {
    return isFirstPage;
  },

  /**
   * @returns {string} The actual location with protocol, domain and pathname
   */
  getActualLocation: function getActualLocation() {
    var _window$location = window.location,
        origin = _window$location.origin,
        pathname = _window$location.pathname;
    return "" + origin + pathname;
  }
};
/**
 * Get the correct page referrer for SPA navigations
 * @returns {string} referrer
 */

export var getPageReferrer = function getPageReferrer() {
  // get the referrer from the previous location if available, fallback to the document
  return actualReferrer || utils.getDocumentReferrer();
};
/**
 * Update page referrer for SPA navigations
 */

export var updatePageReferrer = function updatePageReferrer() {
  // first time we call the update page we don't do nothing to keep correct referrer
  if (utils.checkIsFirstPage()) {
    isFirstPage = false;
    return;
  } // mutate actualReferrer with what will be the new referrer


  actualReferrer = utils.getActualLocation();
};